# Format Specification Elections

As file formats, CSV, XLS or XLSX files are accepted, which are generated by the electoral programs "elections (SESAM)" and "Wabsti elections and votes (VRSG)", or by the web application itself. If a table is to be created by hand, then the format of the web application is the easiest.

"Municipality" might refer to a district, ward, etc.

## Content

[SESAM Majorz](#sesam-majorz)

[SESAM Proporz](#sesam-proporz)

[Wabsti Majorz](#wabsti-majorz)

[Wabsti Proporz](#wabsti-proporz)

[OneGov](#onegov)


## SESAM Majorz

The SESAM export format directly contains all the required data. There is one line per candidate and municipality.

### Columns

The following columns will be evaluated and should exist at the least:

- **Anzahl Sitze** (Number seats)
- **Wahlkreis-Nr** (Electoral district number)
- **Anzahl Gemeinden** (Number municipalities)
- **Stimmberechtigte** (Entitled to vote)
- **Wahlzettel** (Ballots)
- **Ungültige Wahlzettel** (Invalid ballots)
- **Leere Wahlzettel** (Empty ballots)
- **Leere Stimmen** (Empty votes)
- **Ungueltige Stimmen** (Invalid votes)
- **Kandidaten-Nr** (Candidate number)
- **Gewaehlt** (Elected)
- **Name** (Name)
- **Vorname** (First name)
- **Stimmen** (Votes)

### Temporary results

The election is considered not counted if the amount of counted municipalities in `Anzahl Gemeinden` (number seats) does not match total number of municipalities. Municipalities that are not yet counted are not included in the data.

### Template

[election_sesam_majorz.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_sesam_majorz.csv)

## SESAM Proporz

The SESAM export format directly contains all the required data. There is one line per candidate and municipality.

### Columns

The following columns will be evaluated and should exist at the least:

- **Anzahl Sitze** (Number seats)
- **Wahlkreis-Nr** (Electoral district number)
- **Stimmberechtigte** (Entitled to vote)
- **Wahlzettel** (Ballots)
- **Ungültige Wahlzettel** (Invalid ballots)
- **Leere Wahlzettel** (Empty ballots)
- **Leere Stimmen** (Empty votes)
- **Listen-Nr** (List number)
- **Partei-ID** (Party ID)
- **Parteibezeichnung** (Party description)
- **HLV-Nr**
- **ULV-Nr**
- **Anzahl Sitze Liste** (Number seats list)
- **Kandidatenstimmen unveränderte Wahlzettel** (Candidate votes unchanged ballot, part of list vote)
- **Zusatzstimmen unveränderte Wahlzettel** (Additional votes unchanged ballot, part of list vote)
- **Kandidatenstimmen veränderte Wahlzettel** (Candidate vote changed ballot, part of list vote)
- **Zusatzstimmen veränderte Wahlzettel** (Additional votes changed ballot, part of list vote)
- **Kandidaten-Nr** (Candidate number)
- **Gewählt** (Elected)
- **Name** (Name)
- **Vorname** (First name)
- **Stimmen Total aus Wahlzettel** (Vote total from ballot)
- **Anzahl Gemeinden** (Number municipalities)
- **Ungueltige Stimmen** (Invalid votes)

### Temporary results

The election is considered not counted if the amount of counted municipalities in `Anzahl Gemeinden` (number seats) does not match total number of municipalities. Municipalities that are not yet counted are not included in the data.

### Template

[election_sesam_proporz.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_sesam_proporz.csv)

## Wabsti Majorz

The file format needs two individual charts: the data export and the list of elected candidates.

### Columns data export

In the data export, there is a row for each municipality, candidates are arranged in columns. The following columns will be evaluated and should exist:

- **AnzMandate**
- **BFS**
- **StimmBer**
- **StimmAbgegeben**
- **StimmLeer**
- **StimmUngueltig**
- **StimmGueltig**

As well as for each candidate:

- **KandID_`x`**
- **KandName_`x`**
- **KandVorname_`x`**
- **Stimmen_`x`**

Additionally the empty and invalid votes as well as candidates will be captured by the following candidate names:

- **KandName_`x` = 'Leere Zeilen'** (Empty votes)
- **KandName_`x` = 'Ungültige Stimmen'** (Invalid votes)

### Columns candidate results

Because the file format does not supply any information on the elected candidate, those must be included in a second column. Each row consists of one elected candidate with the following columns:

- **ID : ID of the candidate (`KandID_x`).**
- **Name : The surname of the candidate.**
- **Vorname : The first name of the candidate.**

### Temporary results

The file format does not contain any clear information on whether the overall election is completely counted. This information must be given directly on the form for the data upload.

The file format also does not contain any information on whether an individual municipality is completely counted. Therefore, as long as the entire election is not completed, no progress notification will be shown for Wabsti. If municipalities are missing entirely in the results, they are considered not yet counted.

### Templates

[election_wabsti_majorz_results.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_wabsti_majorz_results.csv)

[election_wabsti_majorz_candidates.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_wabsti_majorz_candidates.csv)

## Wabsti Proporz

The file format needs four individual charts: the data export of the results, the data export of the statistics, the list connections and the list elected candidates.

### Columns data export of the results

There is a line per candidate and municipality in the data export. The following columns will be evaluated and should exist:

- **Einheit_BFS**
- **Kand_Nachname**
- **Kand_Vorname**
- **Liste_KandID**
- **Liste_ID**
- **Liste_Code**
- **Kand_StimmenTotal**
- **Liste_ParteistimmenTotal**

### Columns data export of the statistic

The file with the statistics of the individual municipalities should contain the following columns:

- **Einheit_BFS**
- **StimBerTotal**
- **WZEingegangen**
- **WZLeer**
- **WZUngueltig**
- **StmWZVeraendertLeerAmtlLeer**

### Columns list connections

The file with list connections should contain the following columns:

- **Liste**
- **LV**
- **LUV**

### Columns candidate results

Because the file format does not supply any information on the elected candidate, those must be included in a second column. Each row consists of one elected candidate with the following columns:

- **ID** : ID of the candidate (`Liste_KandID`).
- **Name** : The surname of the candidate.
- **Vorname** : The first name of the candidate.

### Temporary results

The file format does not contain any clear information on whether the overall election is completely counted. This information must be given directly on the form for the data upload.

The file format also does not contain any information on whether an individual municipality is completely counted. Therefore, as long as the entire election is not completed, no progress notification will be shown for Wabsti. If municipalities are missing entirely in the results, they are considered not yet counted.

### Templates

[election_wabsti_proporz_results.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_wabsti_proporz_results.csv)

[election_wabsti_proporz_statistics.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_wabsti_proporz_statistics.csv)

[election_wabsti_proporz_list_connections.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_wabsti_proporz_list_connections.csv)

[election_wabsti_proporz_candidates.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_wabsti_proporz_candidates.csv)


## OneGov

The format, which will be used by the web application for the export, consists of a single file per election. There is a row for each municipality and candidate.

### Columns

The following columns will be evaluated and should exist:

- **election_absolute_majority**: Absolute majority of the election, only if Majorz election.
- **election_counted_entities**: Number of counted municipalities. If `election_counted_entities = election_total_entities`, then the election is considered completely counted.
- **election_total_entities**: Total number of municipalities. If no definite information about the status of the election is possible (because the election was imported by Wabsti), then this value is `0`.
- **entity_id**: BFS number of the municipality.
- **entity_elegible_voters**: Number of persons entitled to vote in municipality.
- **entity_received_ballots**: Number of submitted ballots in municipality.
- **entity_blank_ballots**: Number empty ballots in municipality.
- **entity_invalid_ballots**: Number invalid ballots in municipality.
- **entity_blank_votes**: Number empty votes in municipality.
- **entity_invalid_votes**: Number invalid votes in municipality. Zero if Proporz election.
- **list_name**: Name of list of candidate. Only with Proporz elections.
- **list_id**: ID of the list of the candidate. Only with Proporz elections.
- **list_number_of_mandates**: Total number of mandates of the list. Only with Proporz elections.
- **list_votes**: Total number if list votes. Only with Proporz elections.
- **list_connection**: ID of the list connection. Only with Proporz elections.
- **list_connection_parent**: ID of the superordinate list connection. Only with Proporz elections and if it is a sub-list connection.
- **candidate_family_name**: Surname of the candidate.
- **candidate_first_name**: First name of the candidate.
- **candidate_elected**: True, if the candidate was elected.
- **candidate_votes**: Number of candidate votes in municipality.

### Temporary results

The election is considered not yet completely counted, if `election_counted_entities` and `election_total_entities` are not a match. If  `election_total_entities = 0`, then no clear information is possible about the status of the election (because the election was imported by Wabsti).

Not yet completely counted municipalities are not included in the files.

### Template

[election_onegov_majorz.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_onegov_majorz.csv)

[election_onegov_proporz.csv](https://raw.githubusercontent.com/OneGov/onegov.election_day/master/docs/templates/election_onegov_proporz.csv)
